ReplayBufferBuilder

Struct ReplayBufferBuilder 

pub struct ReplayBufferBuilder { /* private fields */ }
Builder for replay buffer outputs

Implementations

Source

impl ReplayBufferBuilder

pub fn new<T: Into<ObsString>, K: Into<ObsPath>>( context: ObsContext, name: T, directory_path: K, ) -> Self

Creates a new ReplayBufferBuilder with default settings.

pub fn settings(self, settings: ReplayBufferSettings) -> Self

Sets the replay buffer settings.

pub fn max_time_sec(self, seconds: i64) -> Self

Sets the maximum time to keep in buffer (seconds).

pub fn max_size_mb(self, megabytes: i64) -> Self

Sets the maximum buffer size (megabytes).

pub fn format<S: Into<ObsString>>(self, format: S) -> Self

Sets the filename format string.

pub fn extension<S: Into<ObsString>>(self, extension: S) -> Self

Sets the file extension.

pub fn allow_spaces(self, allow: bool) -> Self

Sets whether to allow spaces in filenames.

pub fn video_bitrate(self, bitrate: u32) -> Self

Sets the video bitrate in Kbps.

pub fn audio_bitrate(self, bitrate: u32) -> Self

Sets the audio bitrate in Kbps.

pub fn x264_encoder(self, preset: X264Preset) -> Self

Sets the video encoder to x264.

pub fn hardware_encoder( self, codec: HardwareCodec, preset: HardwarePreset, ) -> Self

Sets the video encoder to a generic hardware encoder.

pub fn build(self) -> Result<ObsReplayBufferOutputRef, ObsError>

Builds and returns the configured replay buffer output.