pub struct ReplayBufferSettings { /* private fields */ }Expand description
Settings for replay buffer output
Implementations
Sourceimpl ReplayBufferSettings
impl ReplayBufferSettings
Sourcepub fn with_max_time_sec(self, seconds: i64) -> Self
pub fn with_max_time_sec(self, seconds: i64) -> Self
Sets the maximum time to keep in buffer (seconds).
Sourcepub fn with_max_size_mb(self, megabytes: i64) -> Self
pub fn with_max_size_mb(self, megabytes: i64) -> Self
Sets the maximum buffer size (megabytes).
Sourcepub fn with_format<S: Into<ObsString>>(self, format: S) -> Self
pub fn with_format<S: Into<ObsString>>(self, format: S) -> Self
Sets the filename format string.
Sourcepub fn with_extension<S: Into<ObsString>>(self, extension: S) -> Self
pub fn with_extension<S: Into<ObsString>>(self, extension: S) -> Self
Sets the file extension.
Sourcepub fn with_allow_spaces(self, allow: bool) -> Self
pub fn with_allow_spaces(self, allow: bool) -> Self
Sets whether to allow spaces in filenames.
Sourcepub fn with_video_bitrate(self, bitrate: u32) -> Self
pub fn with_video_bitrate(self, bitrate: u32) -> Self
Sets the video bitrate in Kbps.
Sourcepub fn with_audio_bitrate(self, bitrate: u32) -> Self
pub fn with_audio_bitrate(self, bitrate: u32) -> Self
Sets the audio bitrate in Kbps.
Sourcepub fn with_x264_encoder(self, preset: X264Preset) -> Self
pub fn with_x264_encoder(self, preset: X264Preset) -> Self
Sets the video encoder to use x264 software encoding.
Sourcepub fn with_hardware_encoder(
self,
codec: HardwareCodec,
preset: HardwarePreset,
) -> Self
pub fn with_hardware_encoder( self, codec: HardwareCodec, preset: HardwarePreset, ) -> Self
Sets the video encoder to use a generic hardware encoder for the given codec.
Sourcepub fn with_custom_video_encoder(self, encoder: ObsVideoEncoderType) -> Self
pub fn with_custom_video_encoder(self, encoder: ObsVideoEncoderType) -> Self
Sets a custom video encoder.
Sourcepub fn with_custom_encoder_settings<S: Into<String>>(self, settings: S) -> Self
pub fn with_custom_encoder_settings<S: Into<String>>(self, settings: S) -> Self
Sets custom encoder settings.
Sourcepub fn with_audio_encoder(self, encoder: AudioEncoder) -> Self
pub fn with_audio_encoder(self, encoder: AudioEncoder) -> Self
Sets the audio encoder.